@@ -400,7 +400,7 @@ char *read_equations_from_file
    }
 }
 
-int scan_number_of_variables ( int nc, char *eqs, int *dim )
+int scan_number_of_variables ( int nc, const char *eqs, int *dim )
 {
    int fail = 0;
    int i,b[nc];
@@ -601,7 +601,7 @@ char *read_solution_banner_and_string ( FILE *fp, int k, int *len, int *dim )
 }
 
 int varbprec_Newton_Laurent_step
- ( int dim, int wanted, int maxitr, int maxprc, int ns, char *s )
+ ( int dim, int wanted, int maxitr, int maxprc, int ns, const char *s )
 {
    int i,fail;
    int a[5];
@@ -630,7 +630,7 @@ int read_standard_target_system ( void )
    return fail;
 }
 
-int read_standard_target_system_from_file ( int n, char* filename )
+int read_standard_target_system_from_file ( int n, const char* filename )
 {
    int b[n],i,fail;
    double *c;
@@ -650,7 +650,7 @@ int read_dobldobl_target_system ( void )
    return fail;
 }
 
-int read_dobldobl_target_system_from_file ( int n, char* filename )
+int read_dobldobl_target_system_from_file ( int n, const char* filename )
 {
    int b[n],i,fail;
    double *c;
@@ -670,7 +670,7 @@ int read_quaddobl_target_system ( void )
    return fail;
 }
 
-int read_quaddobl_target_system_from_file ( int n, char* filename )
+int read_quaddobl_target_system_from_file ( int n, const char* filename )
 {
    int b[n],i,fail;
    double *c;
@@ -691,7 +691,7 @@ int read_multprec_target_system ( int decimals )
 }
 
 int read_multprec_target_system_from_file
-  ( int decimals, int n, char* filename )
+  ( int decimals, int n, const char* filename )
 {
    int b[n],i,fail;
    int a[2];
@@ -746,7 +746,7 @@ int read_standard_start_system ( void )
    return fail;
 }
 
-int read_standard_start_system_from_file ( int n, char* filename )
+int read_standard_start_system_from_file ( int n, const char* filename )
 {
    int b[n],i,fail;
    double *c;
@@ -766,7 +766,7 @@ int read_dobldobl_start_system ( void )
    return fail;
 }
 
-int read_dobldobl_start_system_from_file ( int n, char* filename )
+int read_dobldobl_start_system_from_file ( int n, const char* filename )
 {
    int b[n],i,fail;
    double *c;
@@ -786,7 +786,7 @@ int read_quaddobl_start_system ( void )
    return fail;
 }
 
-int read_quaddobl_start_system_from_file ( int n, char* filename )
+int read_quaddobl_start_system_from_file ( int n, const char* filename )
 {
    int b[n],i,fail;
    double *c;
